# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.apimanagement import ApiManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestApiManagementWorkspaceApiOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(ApiManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_list_by_service(self, resource_group):
        response = self.client.workspace_api.list_by_service(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_version="2024-05-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_get_entity_tag(self, resource_group):
        response = self.client.workspace_api.get_entity_tag(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_get(self, resource_group):
        response = self.client.workspace_api.get(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_begin_create_or_update(self, resource_group):
        response = self.client.workspace_api.begin_create_or_update(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            parameters={
                "apiRevision": "str",
                "apiRevisionDescription": "str",
                "apiType": "str",
                "apiVersion": "str",
                "apiVersionDescription": "str",
                "apiVersionSet": {
                    "description": "str",
                    "id": "str",
                    "name": "str",
                    "versionHeaderName": "str",
                    "versionQueryName": "str",
                    "versioningScheme": "str",
                },
                "apiVersionSetId": "str",
                "authenticationSettings": {
                    "oAuth2": {"authorizationServerId": "str", "scope": "str"},
                    "oAuth2AuthenticationSettings": [{"authorizationServerId": "str", "scope": "str"}],
                    "openid": {"bearerTokenSendingMethods": ["str"], "openidProviderId": "str"},
                    "openidAuthenticationSettings": [{"bearerTokenSendingMethods": ["str"], "openidProviderId": "str"}],
                },
                "contact": {"email": "str", "name": "str", "url": "str"},
                "description": "str",
                "displayName": "str",
                "format": "str",
                "isCurrent": bool,
                "isOnline": bool,
                "license": {"name": "str", "url": "str"},
                "path": "str",
                "protocols": ["str"],
                "provisioningState": "str",
                "serviceUrl": "str",
                "sourceApiId": "str",
                "subscriptionKeyParameterNames": {"header": "str", "query": "str"},
                "subscriptionRequired": bool,
                "termsOfServiceUrl": "str",
                "translateRequiredQueryParameters": "str",
                "type": "str",
                "value": "str",
                "wsdlSelector": {"wsdlEndpointName": "str", "wsdlServiceName": "str"},
            },
            api_version="2024-05-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_update(self, resource_group):
        response = self.client.workspace_api.update(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            if_match="str",
            parameters={
                "apiRevision": "str",
                "apiRevisionDescription": "str",
                "apiVersion": "str",
                "apiVersionDescription": "str",
                "apiVersionSetId": "str",
                "authenticationSettings": {
                    "oAuth2": {"authorizationServerId": "str", "scope": "str"},
                    "oAuth2AuthenticationSettings": [{"authorizationServerId": "str", "scope": "str"}],
                    "openid": {"bearerTokenSendingMethods": ["str"], "openidProviderId": "str"},
                    "openidAuthenticationSettings": [{"bearerTokenSendingMethods": ["str"], "openidProviderId": "str"}],
                },
                "contact": {"email": "str", "name": "str", "url": "str"},
                "description": "str",
                "displayName": "str",
                "isCurrent": bool,
                "isOnline": bool,
                "license": {"name": "str", "url": "str"},
                "path": "str",
                "protocols": ["str"],
                "serviceUrl": "str",
                "subscriptionKeyParameterNames": {"header": "str", "query": "str"},
                "subscriptionRequired": bool,
                "termsOfServiceUrl": "str",
                "type": "str",
            },
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_delete(self, resource_group):
        response = self.client.workspace_api.delete(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            if_match="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...



# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
from azure.appconfiguration.provider import (
    SettingSelector,
    AzureAppConfigurationKeyVaultOptions,
    AzureAppConfigurationProvider,
)
from devtools_testutils import recorded_by_proxy
from preparers import app_config_decorator
from testcase import AppConfigTestCase, has_feature_flag
import datetime
from unittest.mock import patch
from test_constants import FEATURE_MANAGEMENT_KEY
from unittest.mock import MagicMock, patch
from azure.appconfiguration.provider._azureappconfigurationproviderbase import (
    delay_failure,
    update_correlation_context_header,
)


def sleep(seconds):
    assert isinstance(seconds, float)


class TestAppConfigurationProvider(AppConfigTestCase):
    # method: provider_creation
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_creation(self, appconfiguration_connection_string, appconfiguration_keyvault_secret_url):
        client = self.create_client(
            appconfiguration_connection_string,
            keyvault_secret_url=appconfiguration_keyvault_secret_url,
            feature_flag_enabled=True,
        )
        assert client["message"] == "hi"
        assert client["my_json"]["key"] == "value"
        assert ".appconfig.featureflag/Alpha" not in client
        assert FEATURE_MANAGEMENT_KEY in client
        assert has_feature_flag(client, "Alpha")

    # method: provider_trim_prefixes
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_trim_prefixes(self, appconfiguration_connection_string, appconfiguration_keyvault_secret_url):
        trimmed = {"test."}
        client = self.create_client(
            appconfiguration_connection_string,
            trim_prefixes=trimmed,
            keyvault_secret_url=appconfiguration_keyvault_secret_url,
            feature_flag_enabled=True,
        )
        assert client["message"] == "hi"
        assert client["my_json"]["key"] == "value"
        assert client["trimmed"] == "key"
        assert "test.trimmed" not in client
        assert FEATURE_MANAGEMENT_KEY in client
        assert has_feature_flag(client, "Alpha")

    # method: provider_selectors
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_selectors(self, appconfiguration_connection_string, appconfiguration_keyvault_secret_url):
        selects = {SettingSelector(key_filter="message*", label_filter="dev")}
        client = self.create_client(
            appconfiguration_connection_string,
            selects=selects,
            keyvault_secret_url=appconfiguration_keyvault_secret_url,
        )
        assert client["message"] == "test"
        assert "test.trimmed" not in client
        assert FEATURE_MANAGEMENT_KEY not in client

    # method: provider_selectors
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_key_vault_reference(
        self, appconfiguration_connection_string, appconfiguration_keyvault_secret_url
    ):
        selects = {SettingSelector(key_filter="*", label_filter="prod")}
        client = self.create_client(
            appconfiguration_connection_string,
            selects=selects,
            keyvault_secret_url=appconfiguration_keyvault_secret_url,
        )
        assert client["secret"] == "Very secret value"

    # method: provider_selectors
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_secret_resolver(self, appconfiguration_connection_string):
        selects = {SettingSelector(key_filter="*", label_filter="prod")}
        client = self.create_client(
            appconfiguration_connection_string, selects=selects, secret_resolver=secret_resolver
        )
        assert client["secret"] == "Reslover Value"

    # method: provider_selectors
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_key_vault_reference_options(
        self, appconfiguration_connection_string, appconfiguration_keyvault_secret_url
    ):
        selects = {SettingSelector(key_filter="*", label_filter="prod")}
        key_vault_options = AzureAppConfigurationKeyVaultOptions()
        client = self.create_client(
            appconfiguration_connection_string,
            selects=selects,
            keyvault_secret_url=appconfiguration_keyvault_secret_url,
            key_vault_options=key_vault_options,
        )
        assert client["secret"] == "Very secret value"

    # method: provider_selectors
    @recorded_by_proxy
    @app_config_decorator
    def test_provider_secret_resolver_options(self, appconfiguration_connection_string):
        selects = {SettingSelector(key_filter="*", label_filter="prod")}
        key_vault_options = AzureAppConfigurationKeyVaultOptions(secret_resolver=secret_resolver)
        client = self.create_client(
            appconfiguration_connection_string, selects=selects, key_vault_options=key_vault_options
        )
        assert client["secret"] == "Reslover Value"

    # method: delay_failure
    @patch("time.sleep", side_effect=sleep)
    def test_delay_failure(self, mock_sleep, **kwargs):
        start_time = datetime.datetime.now()
        delay_failure(start_time)
        assert mock_sleep.call_count == 1

        mock_sleep.reset_mock()
        start_time = datetime.datetime.now() - datetime.timedelta(seconds=10)
        delay_failure(start_time)
        mock_sleep.assert_not_called()

    def test_process_key_value_content_type(self):
        with patch(
            "azure.appconfiguration.provider._azureappconfigurationprovider.ConfigurationClientManager"
        ) as MockClientManager:
            # Mock the client manager and its methods
            mock_client_manager = MockClientManager.return_value
            mock_client_manager.load_configuration_settings.return_value = [
                {"key": "test_key", "value": '{"key": "value"}', "content_type": "application/json"}
            ]

            # Create the provider with the mocked client manager
            provider = AzureAppConfigurationProvider(connection_string="mock_connection_string")
            provider._replica_client_manager = mock_client_manager

            # Call the method to process key-value pairs
            processed_value = provider._process_key_value(
                MagicMock(content_type="application/json", value='{"key": "value"}')
            )

            # Assert the processed value is as expected
            assert processed_value == {"key": "value"}
            assert provider._uses_ai_configuration == False
            assert provider._uses_aicc_configuration == False
            headers = update_correlation_context_header(
                {},
                "fake-request",
                0,
                False,
                [],
                False,
                False,
                False,
                provider._uses_ai_configuration,
                provider._uses_aicc_configuration,
            )
            assert headers["Correlation-Context"] == "RequestType=fake-request"

            mock_client_manager.load_configuration_settings.return_value = [
                {
                    "key": "test_key",
                    "value": '{"key": "value"}',
                    "content_type": "https://azconfig.io/mime-profiles/ai/",
                }
            ]
            processed_value = provider._process_key_value(
                MagicMock(
                    content_type='application/json; profile="https://azconfig.io/mime-profiles/ai/"',
                    value='{"key": "value"}',
                )
            )

            assert processed_value == {"key": "value"}
            assert provider._uses_ai_configuration == True
            assert provider._uses_aicc_configuration == False
            headers = update_correlation_context_header(
                {},
                "fake-request",
                0,
                False,
                [],
                False,
                False,
                False,
                provider._uses_ai_configuration,
                provider._uses_aicc_configuration,
            )
            assert headers["Correlation-Context"] == "RequestType=fake-request,Features=AI"

            mock_client_manager.load_configuration_settings.return_value = [
                {
                    "key": "test_key",
                    "value": '{"key": "value"}',
                    "content_type": 'application/json; profile="https://azconfig.io/mime-profiles/ai/chat-completion"',
                }
            ]
            processed_value = provider._process_key_value(
                MagicMock(
                    content_type='application/json; profile="https://azconfig.io/mime-profiles/ai/chat-completion"',
                    value='{"key": "value"}',
                )
            )

            assert processed_value == {"key": "value"}
            assert provider._uses_ai_configuration == True
            assert provider._uses_aicc_configuration == True
            headers = update_correlation_context_header(
                {},
                "fake-request",
                0,
                False,
                [],
                False,
                False,
                False,
                provider._uses_ai_configuration,
                provider._uses_aicc_configuration,
            )
            assert headers["Correlation-Context"] == "RequestType=fake-request,Features=AI+AICC"


def secret_resolver(secret_id):
    return "Reslover Value"



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import sys
from typing import Any, Callable, Dict, IO, List, Optional, TypeVar, Union, overload

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import AsyncHttpResponse
from azure.core.rest import HttpRequest
from azure.core.tracing.decorator_async import distributed_trace_async
from azure.core.utils import case_insensitive_dict
from azure.mgmt.core.exceptions import ARMErrorFormat

from ... import models as _models
from ..._vendor import _convert_request
from ...operations._steps_operations import (
    build_create_or_update_request,
    build_delete_request,
    build_get_request,
    build_list_request,
)

if sys.version_info >= (3, 8):
    from typing import Literal  # pylint: disable=no-name-in-module, ungrouped-imports
else:
    from typing_extensions import Literal  # type: ignore  # pylint: disable=ungrouped-imports
T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]]


class StepsOperations:
    """
    .. warning::
        **DO NOT** instantiate this class directly.

        Instead, you should access the following operations through
        :class:`~azure.mgmt.deploymentmanager.aio.AzureDeploymentManager`'s
        :attr:`steps` attribute.
    """

    models = _models

    def __init__(self, *args, **kwargs) -> None:
        input_args = list(args)
        self._client = input_args.pop(0) if input_args else kwargs.pop("client")
        self._config = input_args.pop(0) if input_args else kwargs.pop("config")
        self._serialize = input_args.pop(0) if input_args else kwargs.pop("serializer")
        self._deserialize = input_args.pop(0) if input_args else kwargs.pop("deserializer")

    @overload
    async def create_or_update(
        self,
        resource_group_name: str,
        step_name: str,
        step_info: Optional[_models.StepResource] = None,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.StepResource:
        """Creates or updates a rollout step with the given step properties.

        Synchronously creates a new step or updates an existing step.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param step_name: The name of the deployment step. Required.
        :type step_name: str
        :param step_info: The step object. Default value is None.
        :type step_info: ~azure.mgmt.deploymentmanager.models.StepResource
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: StepResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.StepResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def create_or_update(
        self,
        resource_group_name: str,
        step_name: str,
        step_info: Optional[IO] = None,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.StepResource:
        """Creates or updates a rollout step with the given step properties.

        Synchronously creates a new step or updates an existing step.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param step_name: The name of the deployment step. Required.
        :type step_name: str
        :param step_info: The step object. Default value is None.
        :type step_info: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: StepResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.StepResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def create_or_update(
        self,
        resource_group_name: str,
        step_name: str,
        step_info: Optional[Union[_models.StepResource, IO]] = None,
        **kwargs: Any
    ) -> _models.StepResource:
        """Creates or updates a rollout step with the given step properties.

        Synchronously creates a new step or updates an existing step.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param step_name: The name of the deployment step. Required.
        :type step_name: str
        :param step_info: The step object. Is either a model type or a IO type. Default value is None.
        :type step_info: ~azure.mgmt.deploymentmanager.models.StepResource or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: StepResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.StepResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        content_type = kwargs.pop("content_type", _headers.pop("Content-Type", None))  # type: Optional[str]
        cls = kwargs.pop("cls", None)  # type: ClsType[_models.StepResource]

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(step_info, (IO, bytes)):
            _content = step_info
        else:
            if step_info is not None:
                _json = self._serialize.body(step_info, "StepResource")
            else:
                _json = None

        request = build_create_or_update_request(
            resource_group_name=resource_group_name,
            step_name=step_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self.create_or_update.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [201]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("StepResource", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_or_update.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/steps/{stepName}"}  # type: ignore

    @distributed_trace_async
    async def get(self, resource_group_name: str, step_name: str, **kwargs: Any) -> _models.StepResource:
        """Gets the step.

        Gets the step.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param step_name: The name of the deployment step. Required.
        :type step_name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: StepResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.StepResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        cls = kwargs.pop("cls", None)  # type: ClsType[_models.StepResource]

        request = build_get_request(
            resource_group_name=resource_group_name,
            step_name=step_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.get.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("StepResource", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/steps/{stepName}"}  # type: ignore

    @distributed_trace_async
    async def delete(  # pylint: disable=inconsistent-return-statements
        self, resource_group_name: str, step_name: str, **kwargs: Any
    ) -> None:
        """Deletes the step.

        Deletes the step.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param step_name: The name of the deployment step. Required.
        :type step_name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: None or the result of cls(response)
        :rtype: None
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        cls = kwargs.pop("cls", None)  # type: ClsType[None]

        request = build_delete_request(
            resource_group_name=resource_group_name,
            step_name=step_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.delete.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200, 204]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        if cls:
            return cls(pipeline_response, None, {})

    delete.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/steps/{stepName}"}  # type: ignore

    @distributed_trace_async
    async def list(self, resource_group_name: str, **kwargs: Any) -> List[_models.StepResource]:
        """Lists the steps in a resource group.

        Lists the steps in a resource group.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: list of StepResource or the result of cls(response)
        :rtype: list[~azure.mgmt.deploymentmanager.models.StepResource]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        cls = kwargs.pop("cls", None)  # type: ClsType[List[_models.StepResource]]

        request = build_list_request(
            resource_group_name=resource_group_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.list.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("[StepResource]", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    list.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/steps"}  # type: ignore



# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE.txt in the project root for
# license information.
# -------------------------------------------------------------------------
"""Tests for the distributed tracing policy."""
from unittest import mock
import pytest

from corehttp.rest import HttpRequest
from corehttp.runtime.policies import (
    DistributedHttpTracingPolicy,
    UserAgentPolicy,
    RetryPolicy,
)
from corehttp.settings import settings
from corehttp.runtime.pipeline import PipelineRequest, PipelineContext, PipelineResponse, Pipeline
from corehttp.transport import HttpTransport
from corehttp.transport.requests import RequestsTransport
from opentelemetry.trace import format_span_id, format_trace_id
from opentelemetry.instrumentation.requests import RequestsInstrumentor

from utils import HTTP_RESPONSES, create_http_response


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_distributed_tracing_policy(tracing_helper, http_response):
    """Test policy when the HTTP response corresponds to a success."""
    with tracing_helper.tracer.start_as_current_span("Root") as root_span:
        policy = DistributedHttpTracingPolicy()

        request = HttpRequest("GET", "http://localhost/temp?query=query")
        pipeline_request = PipelineRequest(request, PipelineContext(None))
        policy.on_request(pipeline_request)

        response = create_http_response(http_response, request, None, headers=request.headers, status_code=202)

        traceparent = request.headers.get("traceparent")
        assert traceparent is not None
        assert traceparent.startswith("00-")

        policy.on_response(pipeline_request, PipelineResponse(request, response, PipelineContext(None)))

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert len(finished_spans) == 2
    assert finished_spans[0].name == "GET"
    assert finished_spans[0].parent is root_span.get_span_context()

    span_context = finished_spans[0].get_span_context()
    assert traceparent.split("-")[1] == format_trace_id(span_context.trace_id)
    assert traceparent.split("-")[2] == format_span_id(span_context.span_id)

    assert finished_spans[0].attributes.get(policy._HTTP_REQUEST_METHOD) == "GET"
    assert finished_spans[0].attributes.get(policy._URL_FULL) == "http://localhost/temp?query=query"
    assert finished_spans[0].attributes.get(policy._SERVER_ADDRESS) == "localhost"
    assert finished_spans[0].attributes.get(policy._USER_AGENT_ORIGINAL) is None
    assert finished_spans[0].attributes.get(policy._HTTP_RESPONSE_STATUS_CODE) == 202
    assert finished_spans[1].name == "Root"


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_distributed_tracing_policy_error_response(tracing_helper, http_response):
    """Test policy when the HTTP response corresponds to an error."""
    with tracing_helper.tracer.start_as_current_span("Root"):
        policy = DistributedHttpTracingPolicy()

        request = HttpRequest("GET", "http://localhost/temp?query=query")
        pipeline_request = PipelineRequest(request, PipelineContext(None))
        policy.on_request(pipeline_request)

        response = create_http_response(http_response, request, None, headers=request.headers, status_code=403)

        policy.on_response(pipeline_request, PipelineResponse(request, response, PipelineContext(None)))

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert finished_spans[0].name == "GET"
    assert finished_spans[0].attributes.get("error.type") == "403"


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_distributed_tracing_policy_custom_instrumentation_config(tracing_helper, http_response):
    """Test policy when a custom instrumentation config is provided."""
    instrumentation_config = {
        "library_name": "mylibrary",
        "library_version": "1.0.0",
        "attributes": {"namespace": "Sample.Namespace"},
    }
    with tracing_helper.tracer.start_as_current_span("Root"):
        policy = DistributedHttpTracingPolicy(instrumentation_config=instrumentation_config)

        request = HttpRequest("GET", "http://localhost/temp?query=query")
        pipeline_request = PipelineRequest(request, PipelineContext(None))
        policy.on_request(pipeline_request)

        response = create_http_response(http_response, request, None, headers=request.headers, status_code=403)

        policy.on_response(pipeline_request, PipelineResponse(request, response, PipelineContext(None)))

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert finished_spans[0].name == "GET"
    assert finished_spans[0].attributes.get(policy._ERROR_TYPE) == "403"
    assert finished_spans[0].instrumentation_scope.name == "mylibrary"
    assert finished_spans[0].instrumentation_scope.version == "1.0.0"
    assert finished_spans[0].instrumentation_scope.attributes.get("namespace") == "Sample.Namespace"


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_distributed_tracing_policy_with_user_agent_policy(tracing_helper, http_response):
    """Test policy when used with the UserAgentPolicy."""
    with mock.patch.dict("os.environ", {"CORE_HTTP_USER_AGENT": "test-user-agent"}):
        with tracing_helper.tracer.start_as_current_span("Root") as root_span:
            policy = DistributedHttpTracingPolicy()
            user_agent_policy = UserAgentPolicy()

            request = HttpRequest("GET", "http://localhost/temp?query=query")
            pipeline_request = PipelineRequest(request, PipelineContext(None))
            user_agent_policy.on_request(pipeline_request)
            policy.on_request(pipeline_request)

            response = create_http_response(http_response, request, None, headers=request.headers, status_code=202)

            traceparent = request.headers.get("traceparent")
            assert traceparent is not None
            assert traceparent.startswith("00-")

            pipeline_response = PipelineResponse(request, response, PipelineContext(None))

            policy.on_response(pipeline_request, pipeline_response)
            user_agent_policy.on_response(pipeline_request, pipeline_response)

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert len(finished_spans) == 2
    assert finished_spans[0].name == "GET"
    assert finished_spans[0].parent is root_span.get_span_context()

    span_context = finished_spans[0].get_span_context()
    assert traceparent.split("-")[1] == format_trace_id(span_context.trace_id)
    assert traceparent.split("-")[2] == format_span_id(span_context.span_id)

    assert finished_spans[0].attributes.get(policy._HTTP_REQUEST_METHOD) == "GET"
    assert finished_spans[0].attributes.get(policy._URL_FULL) == "http://localhost/temp?query=query"
    assert finished_spans[0].attributes.get(policy._SERVER_ADDRESS) == "localhost"
    assert finished_spans[0].attributes.get(policy._USER_AGENT_ORIGINAL) is not None
    assert finished_spans[0].attributes.get(policy._USER_AGENT_ORIGINAL).endswith("test-user-agent")
    assert finished_spans[0].attributes.get(policy._HTTP_RESPONSE_STATUS_CODE) == 202
    assert finished_spans[1].name == "Root"


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_span_retry_attributes(tracing_helper, http_response):
    """Test that the retry count is added to the span attributes."""

    class MockTransport(HttpTransport):
        def __init__(self):
            self._count = 0

        def __exit__(self, exc_type, exc_val, exc_tb):
            pass

        def close(self):
            pass

        def open(self):
            pass

        def send(self, request, **kwargs):
            self._count += 1
            response = create_http_response(http_response, request, None, status_code=429)
            return response

    http_request = HttpRequest("GET", "http://localhost/")
    retry_policy = RetryPolicy(retry_total=2)
    distributed_tracing_policy = DistributedHttpTracingPolicy()
    transport = MockTransport()

    with tracing_helper.tracer.start_as_current_span("Root") as root_span:
        policies = [retry_policy, distributed_tracing_policy]
        pipeline = Pipeline(transport, policies=policies)
        pipeline.run(http_request)

    assert transport._count == 3

    finished_spans = tracing_helper.exporter.get_finished_spans()
    parent_context = root_span.get_span_context()
    assert len(finished_spans) == 4
    assert finished_spans[0].parent == parent_context
    assert finished_spans[0].attributes.get(distributed_tracing_policy._HTTP_RESEND_COUNT) is None
    assert finished_spans[0].attributes.get(distributed_tracing_policy._URL_FULL) == "http://localhost/"

    assert finished_spans[1].parent == parent_context
    assert finished_spans[1].attributes.get(distributed_tracing_policy._HTTP_RESEND_COUNT) == 1
    assert finished_spans[1].attributes.get(distributed_tracing_policy._URL_FULL) == "http://localhost/"

    assert finished_spans[2].parent == parent_context
    assert finished_spans[2].attributes.get(distributed_tracing_policy._HTTP_RESEND_COUNT) == 2
    assert finished_spans[2].attributes.get(distributed_tracing_policy._URL_FULL) == "http://localhost/"


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_distributed_tracing_policy_with_tracing_options(tracing_helper, http_response):
    """Test policy when tracing options are provided."""
    settings.tracing_enabled = False
    with tracing_helper.tracer.start_as_current_span("Root") as root_span:
        policy = DistributedHttpTracingPolicy()

        request = HttpRequest("GET", "http://localhost/temp?query=query")
        pipeline_request = PipelineRequest(request, PipelineContext(None))
        pipeline_request.context.options["tracing_options"] = {
            "enabled": True,
            "attributes": {"custom_key": "custom_value"},
        }

        policy.on_request(pipeline_request)
        response = create_http_response(http_response, request, None, headers=request.headers, status_code=202)
        policy.on_response(pipeline_request, PipelineResponse(request, response, PipelineContext(None)))

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert len(finished_spans) == 2

    assert finished_spans[0].name == "GET"
    assert finished_spans[0].parent is root_span.get_span_context()

    assert finished_spans[0].attributes.get(policy._HTTP_REQUEST_METHOD) == "GET"
    assert finished_spans[0].attributes.get(policy._URL_FULL) == "http://localhost/temp?query=query"
    assert finished_spans[0].attributes.get(policy._SERVER_ADDRESS) == "localhost"
    assert finished_spans[0].attributes.get(policy._USER_AGENT_ORIGINAL) is None
    assert finished_spans[0].attributes.get(policy._HTTP_RESPONSE_STATUS_CODE) == 202
    assert finished_spans[0].attributes.get("custom_key") == "custom_value"


@pytest.mark.parametrize("http_response", HTTP_RESPONSES)
def test_distributed_tracing_policy_disabled(tracing_helper, http_response):
    """Test policy when tracing is enabled globally but disabled on the operation."""
    with tracing_helper.tracer.start_as_current_span("Root"):
        policy = DistributedHttpTracingPolicy()

        request = HttpRequest("GET", "http://localhost/temp?query=query")
        pipeline_request = PipelineRequest(request, PipelineContext(None))
        pipeline_request.context.options["tracing_options"] = {
            "enabled": False,
        }
        policy.on_request(pipeline_request)
        response = create_http_response(http_response, request, None, headers=request.headers)
        policy.on_response(pipeline_request, PipelineResponse(request, response, PipelineContext(None)))

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert len(finished_spans) == 1
    assert finished_spans[0].name == "Root"


def test_suppress_http_auto_instrumentation(port, tracing_helper):
    """Test that automatic HTTP instrumentation is suppressed when a request is made through the pipeline."""
    # Enable auto-instrumentation for requests.
    requests_instrumentor = RequestsInstrumentor()
    requests_instrumentor.instrument()
    policy = DistributedHttpTracingPolicy()
    transport = RequestsTransport()

    request = HttpRequest("GET", f"http://localhost:{port}/basic/string")
    with Pipeline(transport, policies=[policy]) as pipeline:
        pipeline.run(request)

    finished_spans = tracing_helper.exporter.get_finished_spans()
    assert len(finished_spans) == 1
    assert finished_spans[0].attributes.get(policy._HTTP_REQUEST_METHOD) == "GET"
    assert finished_spans[0].attributes.get(policy._URL_FULL) == f"http://localhost:{port}/basic/string"
    assert finished_spans[0].attributes.get(policy._SERVER_ADDRESS) == "localhost"
    assert finished_spans[0].attributes.get(policy._HTTP_RESPONSE_STATUS_CODE) == 200

    requests_instrumentor.uninstrument()



# coding: utf-8
# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE.txt in the project root for
# license information.
# -------------------------------------------------------------------------
import pytest
from itertools import product

from azure.core.exceptions import IncompleteReadError

from rest_client import MockRestClient
from utils import SYNC_TRANSPORTS, HTTP_REQUESTS, create_http_request


@pytest.mark.parametrize("transport,requesttype", product(SYNC_TRANSPORTS, HTTP_REQUESTS))
def test_sync_transport_short_read_download_stream(port, transport, requesttype):
    client = MockRestClient(port, transport=transport())
    request = create_http_request(requesttype, "GET", "/errors/short-data")
    with pytest.raises(IncompleteReadError):
        response = client.send_request(request, stream=True)
        data = response.iter_bytes()
        content = b""
        for d in data:
            content += d



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AppServicePlanRestrictions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """App Service plans this offer is restricted to."""

    NONE = "None"
    FREE = "Free"
    SHARED = "Shared"
    BASIC = "Basic"
    STANDARD = "Standard"
    PREMIUM = "Premium"


class AuthenticationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Property to select authentication type to access the selected storage account. Available
    options: SystemAssignedIdentity, UserAssignedIdentity, StorageAccountConnectionString.
    """

    SYSTEM_ASSIGNED_IDENTITY = "SystemAssignedIdentity"
    USER_ASSIGNED_IDENTITY = "UserAssignedIdentity"
    STORAGE_ACCOUNT_CONNECTION_STRING = "StorageAccountConnectionString"


class AuthType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Auth Type."""

    ANONYMOUS = "Anonymous"
    USER_CREDENTIALS = "UserCredentials"
    SYSTEM_IDENTITY = "SystemIdentity"
    USER_ASSIGNED = "UserAssigned"


class AutoGeneratedDomainNameLabelScope(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the scope of uniqueness for the default hostname during resource creation."""

    TENANT_REUSE = "TenantReuse"
    SUBSCRIPTION_REUSE = "SubscriptionReuse"
    RESOURCE_GROUP_REUSE = "ResourceGroupReuse"
    NO_REUSE = "NoReuse"


class AutoHealActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Predefined action to be taken."""

    RECYCLE = "Recycle"
    LOG_EVENT = "LogEvent"
    CUSTOM_ACTION = "CustomAction"


class AzureResourceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the Azure resource the hostname is assigned to."""

    WEBSITE = "Website"
    TRAFFIC_MANAGER = "TrafficManager"


class AzureStorageProtocol(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Mounting protocol to use for the storage account."""

    SMB = "Smb"
    HTTP = "Http"
    NFS = "Nfs"


class AzureStorageState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State of the storage account."""

    OK = "Ok"
    INVALID_CREDENTIALS = "InvalidCredentials"
    INVALID_SHARE = "InvalidShare"
    NOT_VALIDATED = "NotValidated"


class AzureStorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of storage."""

    AZURE_FILES = "AzureFiles"
    AZURE_BLOB = "AzureBlob"


class BackupItemStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Backup status."""

    IN_PROGRESS = "InProgress"
    FAILED = "Failed"
    SUCCEEDED = "Succeeded"
    TIMED_OUT = "TimedOut"
    CREATED = "Created"
    SKIPPED = "Skipped"
    PARTIALLY_SUCCEEDED = "PartiallySucceeded"
    DELETE_IN_PROGRESS = "DeleteInProgress"
    DELETE_FAILED = "DeleteFailed"
    DELETED = "Deleted"


class BackupRestoreOperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Operation type."""

    DEFAULT = "Default"
    CLONE = "Clone"
    RELOCATION = "Relocation"
    SNAPSHOT = "Snapshot"
    CLOUD_FS = "CloudFS"


class BasicAuthName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """BasicAuthName."""

    DEFAULT = "default"


class BuildStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The status of the static site build."""

    WAITING_FOR_DEPLOYMENT = "WaitingForDeployment"
    UPLOADING = "Uploading"
    DEPLOYING = "Deploying"
    READY = "Ready"
    FAILED = "Failed"
    DELETING = "Deleting"
    DETACHED = "Detached"


class BuiltInAuthenticationProvider(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The default authentication provider to use when multiple providers are configured.
    This setting is only needed if multiple providers are configured and the unauthenticated client
    action is set to "RedirectToLoginPage".
    """

    AZURE_ACTIVE_DIRECTORY = "AzureActiveDirectory"
    FACEBOOK = "Facebook"
    GOOGLE = "Google"
    MICROSOFT_ACCOUNT = "MicrosoftAccount"
    TWITTER = "Twitter"
    GITHUB = "Github"


class CertificateOrderActionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Action type."""

    CERTIFICATE_ISSUED = "CertificateIssued"
    CERTIFICATE_ORDER_CANCELED = "CertificateOrderCanceled"
    CERTIFICATE_ORDER_CREATED = "CertificateOrderCreated"
    CERTIFICATE_REVOKED = "CertificateRevoked"
    DOMAIN_VALIDATION_COMPLETE = "DomainValidationComplete"
    FRAUD_DETECTED = "FraudDetected"
    ORG_NAME_CHANGE = "OrgNameChange"
    ORG_VALIDATION_COMPLETE = "OrgValidationComplete"
    SAN_DROP = "SanDrop"
    FRAUD_CLEARED = "FraudCleared"
    CERTIFICATE_EXPIRED = "CertificateExpired"
    CERTIFICATE_EXPIRATION_WARNING = "CertificateExpirationWarning"
    FRAUD_DOCUMENTATION_REQUIRED = "FraudDocumentationRequired"
    UNKNOWN = "Unknown"


class CertificateOrderStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current order status."""

    PENDINGISSUANCE = "Pendingissuance"
    ISSUED = "Issued"
    REVOKED = "Revoked"
    CANCELED = "Canceled"
    DENIED = "Denied"
    PENDINGREVOCATION = "Pendingrevocation"
    PENDING_REKEY = "PendingRekey"
    UNUSED = "Unused"
    EXPIRED = "Expired"
    NOT_SUBMITTED = "NotSubmitted"


class CertificateProductType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Certificate product type."""

    STANDARD_DOMAIN_VALIDATED_SSL = "StandardDomainValidatedSsl"
    STANDARD_DOMAIN_VALIDATED_WILD_CARD_SSL = "StandardDomainValidatedWildCardSsl"


class Channels(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """List of channels that this recommendation can apply."""

    NOTIFICATION = "Notification"
    API = "Api"
    EMAIL = "Email"
    WEBHOOK = "Webhook"
    ALL = "All"


class CheckNameResourceTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Resource type used for verification."""

    SITE = "Site"
    SLOT = "Slot"
    HOSTING_ENVIRONMENT = "HostingEnvironment"
    PUBLISHING_USER = "PublishingUser"
    MICROSOFT_WEB_SITES = "Microsoft.Web/sites"
    MICROSOFT_WEB_SITES_SLOTS = "Microsoft.Web/sites/slots"
    MICROSOFT_WEB_HOSTING_ENVIRONMENTS = "Microsoft.Web/hostingEnvironments"
    MICROSOFT_WEB_PUBLISHING_USERS = "Microsoft.Web/publishingUsers"


class ClientCertMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """This composes with ClientCertEnabled setting.


    * ClientCertEnabled: false means ClientCert is ignored.
    * ClientCertEnabled: true and ClientCertMode: Required means ClientCert is required.
    * ClientCertEnabled: true and ClientCertMode: Optional means ClientCert is optional or
    accepted.
    """

    REQUIRED = "Required"
    OPTIONAL = "Optional"
    OPTIONAL_INTERACTIVE_USER = "OptionalInteractiveUser"


class CloneAbilityResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of app."""

    CLONEABLE = "Cloneable"
    PARTIALLY_CLONEABLE = "PartiallyCloneable"
    NOT_CLONEABLE = "NotCloneable"


class ComputeModeOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Shared/dedicated workers."""

    SHARED = "Shared"
    DEDICATED = "Dedicated"
    DYNAMIC = "Dynamic"


class ConnectionStringType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of database."""

    MY_SQL = "MySql"
    SQL_SERVER = "SQLServer"
    SQL_AZURE = "SQLAzure"
    CUSTOM = "Custom"
    NOTIFICATION_HUB = "NotificationHub"
    SERVICE_BUS = "ServiceBus"
    EVENT_HUB = "EventHub"
    API_HUB = "ApiHub"
    DOC_DB = "DocDb"
    REDIS_CACHE = "RedisCache"
    POSTGRE_SQL = "PostgreSQL"


class ContinuousWebJobStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Job status."""

    INITIALIZING = "Initializing"
    STARTING = "Starting"
    RUNNING = "Running"
    PENDING_RESTART = "PendingRestart"
    STOPPED = "Stopped"


class CookieExpirationConvention(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The convention used when determining the session cookie's expiration."""

    FIXED_TIME = "FixedTime"
    IDENTITY_PROVIDER_DERIVED = "IdentityProviderDerived"


class CustomDnsSuffixProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """CustomDnsSuffixProvisioningState."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    DEGRADED = "Degraded"
    IN_PROGRESS = "InProgress"


class CustomDomainStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The status of the custom domain."""

    RETRIEVING_VALIDATION_TOKEN = "RetrievingValidationToken"
    VALIDATING = "Validating"
    ADDING = "Adding"
    READY = "Ready"
    FAILED = "Failed"
    DELETING = "Deleting"
    UNHEALTHY = "Unhealthy"


class CustomHostNameDnsRecordType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the DNS record."""

    C_NAME = "CName"
    A = "A"


class DaprLogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Sets the log level for the Dapr sidecar. Allowed values are debug, info, warn, error. Default
    is info.
    """

    INFO = "info"
    DEBUG = "debug"
    WARN = "warn"
    ERROR = "error"


class DatabaseType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Database type (e.g. SqlAzure / MySql)."""

    SQL_AZURE = "SqlAzure"
    MY_SQL = "MySql"
    LOCAL_MY_SQL = "LocalMySql"
    POSTGRE_SQL = "PostgreSql"


class DayOfWeek(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The day of the week."""

    SUNDAY = "Sunday"
    MONDAY = "Monday"
    TUESDAY = "Tuesday"
    WEDNESDAY = "Wednesday"
    THURSDAY = "Thursday"
    FRIDAY = "Friday"
    SATURDAY = "Saturday"


class DaysOfWeek(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DaysOfWeek."""

    SUNDAY = "Sunday"
    MONDAY = "Monday"
    TUESDAY = "Tuesday"
    WEDNESDAY = "Wednesday"
    THURSDAY = "Thursday"
    FRIDAY = "Friday"
    SATURDAY = "Saturday"


class DefaultAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Default action for main access restriction if no rules are matched."""

    ALLOW = "Allow"
    DENY = "Deny"


class DeploymentBuildStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Deployment build status."""

    TIMED_OUT = "TimedOut"
    RUNTIME_FAILED = "RuntimeFailed"
    BUILD_ABORTED = "BuildAborted"
    BUILD_FAILED = "BuildFailed"
    BUILD_REQUEST_RECEIVED = "BuildRequestReceived"
    BUILD_PENDING = "BuildPending"
    BUILD_IN_PROGRESS = "BuildInProgress"
    BUILD_SUCCESSFUL = "BuildSuccessful"
    POST_BUILD_RESTART_REQUIRED = "PostBuildRestartRequired"
    START_POLLING = "StartPolling"
    START_POLLING_WITH_RESTART = "StartPollingWithRestart"
    RUNTIME_STARTING = "RuntimeStarting"
    RUNTIME_SUCCESSFUL = "RuntimeSuccessful"


class DetectorType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Whether this detector is an Analysis Detector or not."""

    DETECTOR = "Detector"
    ANALYSIS = "Analysis"
    CATEGORY_OVERVIEW = "CategoryOverview"


class DnsType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current DNS type."""

    AZURE_DNS = "AzureDns"
    DEFAULT_DOMAIN_REGISTRAR_DNS = "DefaultDomainRegistrarDns"


class DnsVerificationTestResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DNS verification test result."""

    PASSED = "Passed"
    FAILED = "Failed"
    SKIPPED = "Skipped"


class DomainStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Domain registration status."""

    ACTIVE = "Active"
    AWAITING = "Awaiting"
    CANCELLED = "Cancelled"
    CONFISCATED = "Confiscated"
    DISABLED = "Disabled"
    EXCLUDED = "Excluded"
    EXPIRED = "Expired"
    FAILED = "Failed"
    HELD = "Held"
    LOCKED = "Locked"
    PARKED = "Parked"
    PENDING = "Pending"
    RESERVED = "Reserved"
    REVERTED = "Reverted"
    SUSPENDED = "Suspended"
    TRANSFERRED = "Transferred"
    UNKNOWN = "Unknown"
    UNLOCKED = "Unlocked"
    UNPARKED = "Unparked"
    UPDATED = "Updated"
    JSON_CONVERTER_FAILED = "JsonConverterFailed"


class DomainType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Valid values are Regular domain: Azure will charge the full price of domain registration,
    SoftDeleted: Purchasing this domain will simply restore it and this operation will not cost
    anything.
    """

    REGULAR = "Regular"
    SOFT_DELETED = "SoftDeleted"


class EnterpriseGradeCdnStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State indicating the status of the enterprise grade CDN serving traffic to the static web app."""

    ENABLED = "Enabled"
    ENABLING = "Enabling"
    DISABLED = "Disabled"
    DISABLING = "Disabling"


class ForwardProxyConvention(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The convention used to determine the url of the request made."""

    NO_PROXY = "NoProxy"
    STANDARD = "Standard"
    CUSTOM = "Custom"


class FrequencyUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The unit of time for how often the backup should be executed (e.g. for weekly backup, this
    should be set to Day and FrequencyInterval should be set to 7).
    """

    DAY = "Day"
    HOUR = "Hour"


class FrontEndServiceType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """FrontEndServiceType."""

    NODE_PORT = "NodePort"
    LOAD_BALANCER = "LoadBalancer"


class FtpsState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State of FTP / FTPS service."""

    ALL_ALLOWED = "AllAllowed"
    FTPS_ONLY = "FtpsOnly"
    DISABLED = "Disabled"


class FunctionsDeploymentStorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Property to select Azure Storage type. Available options: blobContainer."""

    BLOB_CONTAINER = "blobContainer"


class HostingEnvironmentStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current status of the App Service Environment."""

    PREPARING = "Preparing"
    READY = "Ready"
    SCALING = "Scaling"
    DELETING = "Deleting"


class HostNameType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the hostname."""

    VERIFIED = "Verified"
    MANAGED = "Managed"


class HostType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Indicates whether the hostname is a standard or repository hostname."""

    STANDARD = "Standard"
    REPOSITORY = "Repository"


class InAvailabilityReasonType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """:code:`<code>Invalid</code>` indicates the name provided does not match Azure App Service
    naming requirements. :code:`<code>AlreadyExists</code>` indicates that the name is already in
    use and is therefore unavailable.
    """

    INVALID = "Invalid"
    ALREADY_EXISTS = "AlreadyExists"


class InsightStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Level of the most severe insight generated by the detector."""

    CRITICAL = "Critical"
    WARNING = "Warning"
    INFO = "Info"
    SUCCESS = "Success"
    NONE = "None"


class IpFilterTag(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Defines what this IP filter will be used for. This is to support IP filtering on proxies."""

    DEFAULT = "Default"
    XFF_PROXY = "XffProxy"
    SERVICE_TAG = "ServiceTag"


class IPMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the IP mode of the app."""

    I_PV4 = "IPv4"
    I_PV6 = "IPv6"
    I_PV4_AND_I_PV6 = "IPv4AndIPv6"


class IssueType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Represents the type of the Detector."""

    SERVICE_INCIDENT = "ServiceIncident"
    APP_DEPLOYMENT = "AppDeployment"
    APP_CRASH = "AppCrash"
    RUNTIME_ISSUE_DETECTED = "RuntimeIssueDetected"
    ASE_DEPLOYMENT = "AseDeployment"
    USER_ISSUE = "UserIssue"
    PLATFORM_ISSUE = "PlatformIssue"
    OTHER = "Other"


class KeyType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The key type."""

    NOT_SPECIFIED = "NotSpecified"
    PRIMARY = "Primary"
    SECONDARY = "Secondary"


class KeyVaultSecretStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of the Key Vault secret."""

    INITIALIZED = "Initialized"
    WAITING_ON_CERTIFICATE_ORDER = "WaitingOnCertificateOrder"
    SUCCEEDED = "Succeeded"
    CERTIFICATE_ORDER_FAILED = "CertificateOrderFailed"
    OPERATION_NOT_PERMITTED_ON_KEY_VAULT = "OperationNotPermittedOnKeyVault"
    AZURE_SERVICE_UNAUTHORIZED_TO_ACCESS_KEY_VAULT = "AzureServiceUnauthorizedToAccessKeyVault"
    KEY_VAULT_DOES_NOT_EXIST = "KeyVaultDoesNotExist"
    KEY_VAULT_SECRET_DOES_NOT_EXIST = "KeyVaultSecretDoesNotExist"
    UNKNOWN_ERROR = "UnknownError"
    EXTERNAL_PRIVATE_KEY = "ExternalPrivateKey"
    UNKNOWN = "Unknown"


class Kind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The workflow kind."""

    STATEFUL = "Stateful"
    STATELESS = "Stateless"


class KubeEnvironmentProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Kubernetes Environment."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    WAITING = "Waiting"
    INITIALIZATION_IN_PROGRESS = "InitializationInProgress"
    INFRASTRUCTURE_SETUP_IN_PROGRESS = "InfrastructureSetupInProgress"
    INFRASTRUCTURE_SETUP_COMPLETE = "InfrastructureSetupComplete"
    SCHEDULED_FOR_DELETE = "ScheduledForDelete"
    UPGRADE_REQUESTED = "UpgradeRequested"
    UPGRADE_FAILED = "UpgradeFailed"


class LoadBalancingMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies which endpoints to serve internally in the Virtual Network for the App Service
    Environment.
    """

    NONE = "None"
    WEB = "Web"
    PUBLISHING = "Publishing"
    WEB_PUBLISHING = "Web, Publishing"


class LogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Log level."""

    OFF = "Off"
    VERBOSE = "Verbose"
    INFORMATION = "Information"
    WARNING = "Warning"
    ERROR = "Error"


class ManagedPipelineMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Managed pipeline mode."""

    INTEGRATED = "Integrated"
    CLASSIC = "Classic"


class ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity."""

    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned, UserAssigned"
    NONE = "None"


class MSDeployLogEntryType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Log entry type."""

    MESSAGE = "Message"
    WARNING = "Warning"
    ERROR = "Error"


class MSDeployProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state."""

    ACCEPTED = "accepted"
    RUNNING = "running"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class MySqlMigrationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of migration operation to be done."""

    LOCAL_TO_REMOTE = "LocalToRemote"
    REMOTE_TO_LOCAL = "RemoteToLocal"


class NotificationLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Level indicating how critical this recommendation can impact."""

    CRITICAL = "Critical"
    WARNING = "Warning"
    INFORMATION = "Information"
    NON_URGENT_SUGGESTION = "NonUrgentSuggestion"


class OpenAuthenticationProviderType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Open authentication policy provider type."""

    AAD = "AAD"


class OperationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The current status of the operation."""

    IN_PROGRESS = "InProgress"
    FAILED = "Failed"
    SUCCEEDED = "Succeeded"
    TIMED_OUT = "TimedOut"
    CREATED = "Created"


class ParameterType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The parameter type."""

    NOT_SPECIFIED = "NotSpecified"
    STRING = "String"
    SECURE_STRING = "SecureString"
    INT = "Int"
    FLOAT = "Float"
    BOOL = "Bool"
    ARRAY = "Array"
    OBJECT = "Object"
    SECURE_OBJECT = "SecureObject"
    INT_ENUM = "Int"


class ProviderOsTypeSelected(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """ProviderOsTypeSelected."""

    WINDOWS = "Windows"
    LINUX = "Linux"
    WINDOWS_FUNCTIONS = "WindowsFunctions"
    LINUX_FUNCTIONS = "LinuxFunctions"
    ALL = "All"


class ProviderStackOsType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """ProviderStackOsType."""

    WINDOWS = "Windows"
    LINUX = "Linux"
    ALL = "All"


class ProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Status of certificate order."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    IN_PROGRESS = "InProgress"
    DELETING = "Deleting"


class PublicCertificateLocation(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Public Certificate Location."""

    CURRENT_USER_MY = "CurrentUserMy"
    LOCAL_MACHINE_MY = "LocalMachineMy"
    UNKNOWN = "Unknown"


class PublishingProfileFormat(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of the format. Valid values are:
    FileZilla3
    WebDeploy -- default
    Ftp.
    """

    FILE_ZILLA3 = "FileZilla3"
    WEB_DEPLOY = "WebDeploy"
    FTP = "Ftp"


class RecurrenceFrequency(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The recurrence frequency."""

    NOT_SPECIFIED = "NotSpecified"
    SECOND = "Second"
    MINUTE = "Minute"
    HOUR = "Hour"
    DAY = "Day"
    WEEK = "Week"
    MONTH = "Month"
    YEAR = "Year"


class RedundancyMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Site redundancy mode."""

    NONE = "None"
    MANUAL = "Manual"
    FAILOVER = "Failover"
    ACTIVE_ACTIVE = "ActiveActive"
    GEO_REDUNDANT = "GeoRedundant"


class RenderingType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Rendering Type."""

    NO_GRAPH = "NoGraph"
    TABLE = "Table"
    TIME_SERIES = "TimeSeries"
    TIME_SERIES_PER_INSTANCE = "TimeSeriesPerInstance"
    PIE_CHART = "PieChart"
    DATA_SUMMARY = "DataSummary"
    EMAIL = "Email"
    INSIGHTS = "Insights"
    DYNAMIC_INSIGHT = "DynamicInsight"
    MARKDOWN = "Markdown"
    DETECTOR = "Detector"
    DROP_DOWN = "DropDown"
    CARD = "Card"
    SOLUTION = "Solution"
    GUAGE = "Guage"
    FORM = "Form"
    CHANGE_SETS = "ChangeSets"
    CHANGE_ANALYSIS_ONBOARDING = "ChangeAnalysisOnboarding"
    CHANGES_VIEW = "ChangesView"
    APP_INSIGHT = "AppInsight"
    DEPENDENCY_GRAPH = "DependencyGraph"
    DOWN_TIME = "DownTime"
    SUMMARY_CARD = "SummaryCard"
    SEARCH_COMPONENT = "SearchComponent"
    APP_INSIGHT_ENABLEMENT = "AppInsightEnablement"


class ResolveStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """ResolveStatus."""

    INITIALIZED = "Initialized"
    RESOLVED = "Resolved"
    INVALID_SYNTAX = "InvalidSyntax"
    MSI_NOT_ENABLED = "MSINotEnabled"
    VAULT_NOT_FOUND = "VaultNotFound"
    SECRET_NOT_FOUND = "SecretNotFound"
    SECRET_VERSION_NOT_FOUND = "SecretVersionNotFound"
    ACCESS_TO_KEY_VAULT_DENIED = "AccessToKeyVaultDenied"
    OTHER_REASONS = "OtherReasons"
    FETCH_TIMED_OUT = "FetchTimedOut"
    UNAUTHORIZED_CLIENT = "UnauthorizedClient"


class ResourceNotRenewableReason(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """ResourceNotRenewableReason."""

    REGISTRATION_STATUS_NOT_SUPPORTED_FOR_RENEWAL = "RegistrationStatusNotSupportedForRenewal"
    EXPIRATION_NOT_IN_RENEWAL_TIME_RANGE = "ExpirationNotInRenewalTimeRange"
    SUBSCRIPTION_NOT_ACTIVE = "SubscriptionNotActive"


class ResourceScopeType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Name of a resource type this recommendation applies, e.g. Subscription, ServerFarm, Site."""

    SERVER_FARM = "ServerFarm"
    SUBSCRIPTION = "Subscription"
    WEB_SITE = "WebSite"


class RouteType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of route this is:
    DEFAULT - By default, every app has routes to the local address ranges specified by RFC1918
    INHERITED - Routes inherited from the real Virtual Network routes
    STATIC - Static route set on the app only

    These values will be used for syncing an app's routes with those from a Virtual Network.
    """

    DEFAULT = "DEFAULT"
    INHERITED = "INHERITED"
    STATIC = "STATIC"


class RuntimeName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Function app runtime name. Available options: dotnet-isolated, node, java, powershell, python,
    custom.
    """

    DOTNET_ISOLATED = "dotnet-isolated"
    NODE = "node"
    JAVA = "java"
    POWERSHELL = "powershell"
    PYTHON = "python"
    CUSTOM = "custom"


class ScmType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SCM type."""

    NONE = "None"
    DROPBOX = "Dropbox"
    TFS = "Tfs"
    LOCAL_GIT = "LocalGit"
    GIT_HUB = "GitHub"
    CODE_PLEX_GIT = "CodePlexGit"
    CODE_PLEX_HG = "CodePlexHg"
    BITBUCKET_GIT = "BitbucketGit"
    BITBUCKET_HG = "BitbucketHg"
    EXTERNAL_GIT = "ExternalGit"
    EXTERNAL_HG = "ExternalHg"
    ONE_DRIVE = "OneDrive"
    VSO = "VSO"
    VSTSRM = "VSTSRM"


class SiteAvailabilityState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Management information availability state for the app."""

    NORMAL = "Normal"
    LIMITED = "Limited"
    DISASTER_RECOVERY_MODE = "DisasterRecoveryMode"


class SiteExtensionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Site extension type."""

    GALLERY = "Gallery"
    WEB_ROOT = "WebRoot"


class SiteLoadBalancing(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Site load balancing."""

    WEIGHTED_ROUND_ROBIN = "WeightedRoundRobin"
    LEAST_REQUESTS = "LeastRequests"
    LEAST_RESPONSE_TIME = "LeastResponseTime"
    WEIGHTED_TOTAL_TRAFFIC = "WeightedTotalTraffic"
    REQUEST_HASH = "RequestHash"
    PER_SITE_ROUND_ROBIN = "PerSiteRoundRobin"
    LEAST_REQUESTS_WITH_TIE_BREAKER = "LeastRequestsWithTieBreaker"


class SiteRuntimeState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SiteRuntimeState."""

    READY = "READY"
    STOPPED = "STOPPED"
    UNKNOWN = "UNKNOWN"


class SkuName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SkuName."""

    FREE = "Free"
    SHARED = "Shared"
    BASIC = "Basic"
    STANDARD = "Standard"
    PREMIUM = "Premium"
    DYNAMIC = "Dynamic"
    ISOLATED = "Isolated"
    ISOLATED_V2 = "IsolatedV2"
    PREMIUM_V2 = "PremiumV2"
    PREMIUM_V3 = "PremiumV3"
    PREMIUM_CONTAINER = "PremiumContainer"
    ELASTIC_PREMIUM = "ElasticPremium"
    ELASTIC_ISOLATED = "ElasticIsolated"
    FLEX_CONSUMPTION = "FlexConsumption"


class SolutionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of Solution."""

    QUICK_SOLUTION = "QuickSolution"
    DEEP_INVESTIGATION = "DeepInvestigation"
    BEST_PRACTICES = "BestPractices"


class SslState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """SSL type."""

    DISABLED = "Disabled"
    SNI_ENABLED = "SniEnabled"
    IP_BASED_ENABLED = "IpBasedEnabled"


class StackPreferredOs(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Function App stack preferred OS."""

    WINDOWS = "Windows"
    LINUX = "Linux"


class StagingEnvironmentPolicy(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State indicating whether staging environments are allowed or not allowed for a static web app."""

    ENABLED = "Enabled"
    DISABLED = "Disabled"


class StatusOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """App Service plan status."""

    READY = "Ready"
    PENDING = "Pending"
    CREATING = "Creating"


class StorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """StorageType."""

    LOCAL_NODE = "LocalNode"
    NETWORK_FILE_SYSTEM = "NetworkFileSystem"


class SupportedTlsVersions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """MinTlsVersion: configures the minimum version of TLS required for SSL requests."""

    ONE0 = "1.0"
    ONE1 = "1.1"
    ONE2 = "1.2"
    ONE3 = "1.3"


class TlsCipherSuites(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The minimum strength TLS cipher suite allowed for an application."""

    TLS_AES256_GCM_SHA384 = "TLS_AES_256_GCM_SHA384"
    TLS_AES128_GCM_SHA256 = "TLS_AES_128_GCM_SHA256"
    TLS_ECDHE_ECDSA_WITH_AES256_GCM_SHA384 = "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384"
    TLS_ECDHE_ECDSA_WITH_AES128_CBC_SHA256 = "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256"
    TLS_ECDHE_ECDSA_WITH_AES128_GCM_SHA256 = "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256"
    TLS_ECDHE_RSA_WITH_AES256_GCM_SHA384 = "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384"
    TLS_ECDHE_RSA_WITH_AES128_GCM_SHA256 = "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256"
    TLS_ECDHE_RSA_WITH_AES256_CBC_SHA384 = "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384"
    TLS_ECDHE_RSA_WITH_AES128_CBC_SHA256 = "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256"
    TLS_ECDHE_RSA_WITH_AES256_CBC_SHA = "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA"
    TLS_ECDHE_RSA_WITH_AES128_CBC_SHA = "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA"
    TLS_RSA_WITH_AES256_GCM_SHA384 = "TLS_RSA_WITH_AES_256_GCM_SHA384"
    TLS_RSA_WITH_AES128_GCM_SHA256 = "TLS_RSA_WITH_AES_128_GCM_SHA256"
    TLS_RSA_WITH_AES256_CBC_SHA256 = "TLS_RSA_WITH_AES_256_CBC_SHA256"
    TLS_RSA_WITH_AES128_CBC_SHA256 = "TLS_RSA_WITH_AES_128_CBC_SHA256"
    TLS_RSA_WITH_AES256_CBC_SHA = "TLS_RSA_WITH_AES_256_CBC_SHA"
    TLS_RSA_WITH_AES128_CBC_SHA = "TLS_RSA_WITH_AES_128_CBC_SHA"


class TriggeredWebJobStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Job status."""

    SUCCESS = "Success"
    FAILED = "Failed"
    ERROR = "Error"


class TriggerTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The trigger type of the function."""

    HTTP_TRIGGER = "HttpTrigger"
    UNKNOWN = "Unknown"


class UnauthenticatedClientAction(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action to take when an unauthenticated client attempts to access the app."""

    REDIRECT_TO_LOGIN_PAGE = "RedirectToLoginPage"
    ALLOW_ANONYMOUS = "AllowAnonymous"


class UnauthenticatedClientActionV2(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action to take when an unauthenticated client attempts to access the app."""

    REDIRECT_TO_LOGIN_PAGE = "RedirectToLoginPage"
    ALLOW_ANONYMOUS = "AllowAnonymous"
    RETURN401 = "Return401"
    RETURN403 = "Return403"


class UpgradeAvailability(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Whether an upgrade is available for this App Service Environment."""

    NONE = "None"
    """No upgrade is currently available for this App Service Environment"""
    READY = "Ready"
    """An upgrade is ready to be manually initiated on this App Service Environment"""


class UpgradePreference(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Upgrade Preference."""

    NONE = "None"
    """No preference on when this App Service Environment will be upgraded"""
    EARLY = "Early"
    """This App Service Environment will be upgraded before others in the same region that have
    Upgrade Preference 'Late'"""
    LATE = "Late"
    """This App Service Environment will be upgraded after others in the same region that have Upgrade
    Preference 'Early'"""
    MANUAL = "Manual"
    """ASEv3 only. Once an upgrade is available, this App Service Environment will wait 10 days for
    the upgrade to be manually initiated. After 10 days the upgrade will begin automatically"""


class UsageState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State indicating whether the app has exceeded its quota usage. Read-only."""

    NORMAL = "Normal"
    EXCEEDED = "Exceeded"


class ValidateResourceTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Resource type used for verification."""

    SERVER_FARM = "ServerFarm"
    SITE = "Site"
    MICROSOFT_WEB_HOSTING_ENVIRONMENTS = "Microsoft.Web/hostingEnvironments"


class WebJobType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Job type."""

    CONTINUOUS = "Continuous"
    TRIGGERED = "Triggered"


class WorkerSizeOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Size of the machines."""

    SMALL = "Small"
    MEDIUM = "Medium"
    LARGE = "Large"
    D1 = "D1"
    D2 = "D2"
    D3 = "D3"
    SMALL_V3 = "SmallV3"
    MEDIUM_V3 = "MediumV3"
    LARGE_V3 = "LargeV3"
    NESTED_SMALL = "NestedSmall"
    NESTED_SMALL_LINUX = "NestedSmallLinux"
    DEFAULT = "Default"


class WorkflowHealthState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the workflow health state."""

    NOT_SPECIFIED = "NotSpecified"
    HEALTHY = "Healthy"
    UNHEALTHY = "Unhealthy"
    UNKNOWN = "Unknown"


class WorkflowProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The workflow provisioning state."""

    NOT_SPECIFIED = "NotSpecified"
    ACCEPTED = "Accepted"
    RUNNING = "Running"
    READY = "Ready"
    CREATING = "Creating"
    CREATED = "Created"
    DELETING = "Deleting"
    DELETED = "Deleted"
    CANCELED = "Canceled"
    FAILED = "Failed"
    SUCCEEDED = "Succeeded"
    MOVING = "Moving"
    UPDATING = "Updating"
    REGISTERING = "Registering"
    REGISTERED = "Registered"
    UNREGISTERING = "Unregistering"
    UNREGISTERED = "Unregistered"
    COMPLETED = "Completed"
    RENEWING = "Renewing"
    PENDING = "Pending"
    WAITING = "Waiting"
    IN_PROGRESS = "InProgress"


class WorkflowSkuName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The sku name."""

    NOT_SPECIFIED = "NotSpecified"
    FREE = "Free"
    SHARED = "Shared"
    BASIC = "Basic"
    STANDARD = "Standard"
    PREMIUM = "Premium"


class WorkflowState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The workflow state."""

    NOT_SPECIFIED = "NotSpecified"
    COMPLETED = "Completed"
    ENABLED = "Enabled"
    DISABLED = "Disabled"
    DELETED = "Deleted"
    SUSPENDED = "Suspended"


class WorkflowStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The workflow status."""

    NOT_SPECIFIED = "NotSpecified"
    PAUSED = "Paused"
    RUNNING = "Running"
    WAITING = "Waiting"
    SUCCEEDED = "Succeeded"
    SKIPPED = "Skipped"
    SUSPENDED = "Suspended"
    CANCELLED = "Cancelled"
    FAILED = "Failed"
    FAULTED = "Faulted"
    TIMED_OUT = "TimedOut"
    ABORTED = "Aborted"
    IGNORED = "Ignored"


class WorkflowTriggerProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The workflow trigger provisioning state."""

    NOT_SPECIFIED = "NotSpecified"
    ACCEPTED = "Accepted"
    RUNNING = "Running"
    READY = "Ready"
    CREATING = "Creating"
    CREATED = "Created"
    DELETING = "Deleting"
    DELETED = "Deleted"
    CANCELED = "Canceled"
    FAILED = "Failed"
    SUCCEEDED = "Succeeded"
    MOVING = "Moving"
    UPDATING = "Updating"
    REGISTERING = "Registering"
    REGISTERED = "Registered"
    UNREGISTERING = "Unregistering"
    UNREGISTERED = "Unregistered"
    COMPLETED = "Completed"



# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
from collections.abc import MutableMapping
from io import IOBase
from typing import Any, Callable, Dict, IO, Optional, TypeVar, Union, overload

from azure.core import PipelineClient
from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.rest import HttpRequest, HttpResponse
from azure.core.tracing.decorator import distributed_trace
from azure.core.utils import case_insensitive_dict
from azure.mgmt.core.exceptions import ARMErrorFormat

from .. import models as _models
from .._configuration import ContainerServiceClientConfiguration
from .._utils.serialization import Deserializer, Serializer

T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, HttpResponse], T, Dict[str, Any]], Any]]

_SERIALIZER = Serializer()
_SERIALIZER.client_side_validation = False


def build_post_request(
    resource_group_name: str, resource_name: str, subscription_id: str, **kwargs: Any
) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2025-02-02-preview"))
    content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ContainerService/managedClusters/{resourceName}/resolvePrivateLinkServiceId",
    )
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str"),
        "resourceGroupName": _SERIALIZER.url(
            "resource_group_name", resource_group_name, "str", max_length=90, min_length=1
        ),
        "resourceName": _SERIALIZER.url(
            "resource_name",
            resource_name,
            "str",
            max_length=63,
            min_length=1,
            pattern=r"^[a-zA-Z0-9]$|^[a-zA-Z0-9][-_a-zA-Z0-9]{0,61}[a-zA-Z0-9]$",
        ),
    }

    _url: str = _url.format(**path_format_arguments)  # type: ignore

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    if content_type is not None:
        _headers["Content-Type"] = _SERIALIZER.header("content_type", content_type, "str")
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="POST", url=_url, params=_params, headers=_headers, **kwargs)


class ResolvePrivateLinkServiceIdOperations:
    """
    .. warning::
        **DO NOT** instantiate this class directly.

        Instead, you should access the following operations through
        :class:`~azure.mgmt.containerservice.v2025_02_02_preview.ContainerServiceClient`'s
        :attr:`resolve_private_link_service_id` attribute.
    """

    models = _models

    def __init__(self, *args, **kwargs):
        input_args = list(args)
        self._client: PipelineClient = input_args.pop(0) if input_args else kwargs.pop("client")
        self._config: ContainerServiceClientConfiguration = input_args.pop(0) if input_args else kwargs.pop("config")
        self._serialize: Serializer = input_args.pop(0) if input_args else kwargs.pop("serializer")
        self._deserialize: Deserializer = input_args.pop(0) if input_args else kwargs.pop("deserializer")
        self._api_version = input_args.pop(0) if input_args else kwargs.pop("api_version")

    @overload
    def post(
        self,
        resource_group_name: str,
        resource_name: str,
        parameters: _models.PrivateLinkResource,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.PrivateLinkResource:
        """Gets the private link service ID for the specified managed cluster.

        Gets the private link service ID for the specified managed cluster.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param resource_name: The name of the managed cluster resource. Required.
        :type resource_name: str
        :param parameters: Parameters required in order to resolve a private link service ID. Required.
        :type parameters: ~azure.mgmt.containerservice.v2025_02_02_preview.models.PrivateLinkResource
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :return: PrivateLinkResource or the result of cls(response)
        :rtype: ~azure.mgmt.containerservice.v2025_02_02_preview.models.PrivateLinkResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    def post(
        self,
        resource_group_name: str,
        resource_name: str,
        parameters: IO[bytes],
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.PrivateLinkResource:
        """Gets the private link service ID for the specified managed cluster.

        Gets the private link service ID for the specified managed cluster.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param resource_name: The name of the managed cluster resource. Required.
        :type resource_name: str
        :param parameters: Parameters required in order to resolve a private link service ID. Required.
        :type parameters: IO[bytes]
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :return: PrivateLinkResource or the result of cls(response)
        :rtype: ~azure.mgmt.containerservice.v2025_02_02_preview.models.PrivateLinkResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace
    def post(
        self,
        resource_group_name: str,
        resource_name: str,
        parameters: Union[_models.PrivateLinkResource, IO[bytes]],
        **kwargs: Any
    ) -> _models.PrivateLinkResource:
        """Gets the private link service ID for the specified managed cluster.

        Gets the private link service ID for the specified managed cluster.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param resource_name: The name of the managed cluster resource. Required.
        :type resource_name: str
        :param parameters: Parameters required in order to resolve a private link service ID. Is either
         a PrivateLinkResource type or a IO[bytes] type. Required.
        :type parameters: ~azure.mgmt.containerservice.v2025_02_02_preview.models.PrivateLinkResource
         or IO[bytes]
        :return: PrivateLinkResource or the result of cls(response)
        :rtype: ~azure.mgmt.containerservice.v2025_02_02_preview.models.PrivateLinkResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map: MutableMapping = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop(
            "api_version", _params.pop("api-version", self._api_version or "2025-02-02-preview")
        )
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.PrivateLinkResource] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(parameters, (IOBase, bytes)):
            _content = parameters
        else:
            _json = self._serialize.body(parameters, "PrivateLinkResource")

        _request = build_post_request(
            resource_group_name=resource_group_name,
            resource_name=resource_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            headers=_headers,
            params=_params,
        )
        _request.url = self._client.format_url(_request.url)

        _stream = False
        pipeline_response: PipelineResponse = self._client._pipeline.run(  # pylint: disable=protected-access
            _request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("PrivateLinkResource", pipeline_response.http_response)

        if cls:
            return cls(pipeline_response, deserialized, {})  # type: ignore

        return deserialized  # type: ignore



# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: set_sip_trunks_sample_async.py
DESCRIPTION:
    This sample shows the usage of asynchronous SIP routing client for replacing the collection of
    currently configured SIP trunks with new values.

USAGE:
    python set_sip_trunks_sample_async.py
        Set the environment variables with your own values before running the sample:
    1) COMMUNICATION_SAMPLES_CONNECTION_STRING - the connection string in your ACS account
    2) COMMUNICATION_SAMPLES_TRUNK_FQDN - FQDN of SipTrunk object to be set
    3) COMMUNICATION_SAMPLES_SIGNALING_PORT - SIP signaling port of SipTrunk object to be set
"""

import os
import asyncio
from azure.communication.phonenumbers.siprouting.aio import SipRoutingClient
from azure.communication.phonenumbers.siprouting import SipTrunk

connection_string = os.getenv("COMMUNICATION_SAMPLES_CONNECTION_STRING")
client = SipRoutingClient.from_connection_string(connection_string)
fqdn = os.getenv("COMMUNICATION_SAMPLES_TRUNK_FQDN")
signaling_port = os.getenv("COMMUNICATION_SAMPLES_SIGNALING_PORT")
TRUNKS = [SipTrunk(fqdn=fqdn, sip_signaling_port=signaling_port)]


async def set_sip_trunks_sample():
    async with client:
        await client.set_trunks(TRUNKS)


if __name__ == "__main__":
    asyncio.run(set_sip_trunks_sample())



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.web.aio import WebSiteManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer
from devtools_testutils.aio import recorded_by_proxy_async

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestWebSiteManagementAppServiceEnvironmentsOperationsAsync(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(WebSiteManagementClient, is_async=True)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list(self, resource_group):
        response = self.client.app_service_environments.list(
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_by_resource_group(self, resource_group):
        response = self.client.app_service_environments.list_by_resource_group(
            resource_group_name=resource_group.name,
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get(self, resource_group):
        response = await self.client.app_service_environments.get(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_create_or_update(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_create_or_update(
                resource_group_name=resource_group.name,
                name="str",
                hosting_environment_envelope={
                    "location": "str",
                    "clusterSettings": [{"name": "str", "value": "str"}],
                    "customDnsSuffixConfiguration": {
                        "certificateUrl": "str",
                        "dnsSuffix": "str",
                        "id": "str",
                        "keyVaultReferenceIdentity": "str",
                        "kind": "str",
                        "name": "str",
                        "provisioningDetails": "str",
                        "provisioningState": "str",
                        "type": "str",
                    },
                    "dedicatedHostCount": 0,
                    "dnsSuffix": "str",
                    "frontEndScaleFactor": 0,
                    "hasLinuxWorkers": bool,
                    "id": "str",
                    "internalLoadBalancingMode": "str",
                    "ipsslAddressCount": 0,
                    "kind": "str",
                    "maximumNumberOfMachines": 0,
                    "multiRoleCount": 0,
                    "multiSize": "str",
                    "name": "str",
                    "networkingConfiguration": {
                        "allowNewPrivateEndpointConnections": bool,
                        "externalInboundIpAddresses": ["str"],
                        "ftpEnabled": bool,
                        "id": "str",
                        "inboundIpAddressOverride": "str",
                        "internalInboundIpAddresses": ["str"],
                        "kind": "str",
                        "linuxOutboundIpAddresses": ["str"],
                        "name": "str",
                        "remoteDebugEnabled": bool,
                        "type": "str",
                        "windowsOutboundIpAddresses": ["str"],
                    },
                    "provisioningState": "str",
                    "status": "str",
                    "suspended": bool,
                    "tags": {"str": "str"},
                    "type": "str",
                    "upgradeAvailability": "str",
                    "upgradePreference": "None",
                    "userWhitelistedIpRanges": ["str"],
                    "virtualNetwork": {"id": "str", "name": "str", "subnet": "str", "type": "str"},
                    "zoneRedundant": bool,
                },
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_delete(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_delete(
                resource_group_name=resource_group.name,
                name="str",
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_update(self, resource_group):
        response = await self.client.app_service_environments.update(
            resource_group_name=resource_group.name,
            name="str",
            hosting_environment_envelope={
                "clusterSettings": [{"name": "str", "value": "str"}],
                "customDnsSuffixConfiguration": {
                    "certificateUrl": "str",
                    "dnsSuffix": "str",
                    "id": "str",
                    "keyVaultReferenceIdentity": "str",
                    "kind": "str",
                    "name": "str",
                    "provisioningDetails": "str",
                    "provisioningState": "str",
                    "type": "str",
                },
                "dedicatedHostCount": 0,
                "dnsSuffix": "str",
                "frontEndScaleFactor": 0,
                "hasLinuxWorkers": bool,
                "id": "str",
                "internalLoadBalancingMode": "str",
                "ipsslAddressCount": 0,
                "kind": "str",
                "maximumNumberOfMachines": 0,
                "multiRoleCount": 0,
                "multiSize": "str",
                "name": "str",
                "networkingConfiguration": {
                    "allowNewPrivateEndpointConnections": bool,
                    "externalInboundIpAddresses": ["str"],
                    "ftpEnabled": bool,
                    "id": "str",
                    "inboundIpAddressOverride": "str",
                    "internalInboundIpAddresses": ["str"],
                    "kind": "str",
                    "linuxOutboundIpAddresses": ["str"],
                    "name": "str",
                    "remoteDebugEnabled": bool,
                    "type": "str",
                    "windowsOutboundIpAddresses": ["str"],
                },
                "provisioningState": "str",
                "status": "str",
                "suspended": bool,
                "type": "str",
                "upgradeAvailability": "str",
                "upgradePreference": "None",
                "userWhitelistedIpRanges": ["str"],
                "virtualNetwork": {"id": "str", "name": "str", "subnet": "str", "type": "str"},
                "zoneRedundant": bool,
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_capacities(self, resource_group):
        response = self.client.app_service_environments.list_capacities(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_vip_info(self, resource_group):
        response = await self.client.app_service_environments.get_vip_info(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_change_vnet(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_change_vnet(
                resource_group_name=resource_group.name,
                name="str",
                vnet_info={"id": "str", "name": "str", "subnet": "str", "type": "str"},
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_ase_custom_dns_suffix_configuration(self, resource_group):
        response = await self.client.app_service_environments.get_ase_custom_dns_suffix_configuration(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_update_ase_custom_dns_suffix_configuration(self, resource_group):
        response = await self.client.app_service_environments.update_ase_custom_dns_suffix_configuration(
            resource_group_name=resource_group.name,
            name="str",
            custom_dns_suffix_configuration={
                "certificateUrl": "str",
                "dnsSuffix": "str",
                "id": "str",
                "keyVaultReferenceIdentity": "str",
                "kind": "str",
                "name": "str",
                "provisioningDetails": "str",
                "provisioningState": "str",
                "type": "str",
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_delete_ase_custom_dns_suffix_configuration(self, resource_group):
        response = await self.client.app_service_environments.delete_ase_custom_dns_suffix_configuration(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_ase_v3_networking_configuration(self, resource_group):
        response = await self.client.app_service_environments.get_ase_v3_networking_configuration(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_update_ase_networking_configuration(self, resource_group):
        response = await self.client.app_service_environments.update_ase_networking_configuration(
            resource_group_name=resource_group.name,
            name="str",
            ase_networking_configuration={
                "allowNewPrivateEndpointConnections": bool,
                "externalInboundIpAddresses": ["str"],
                "ftpEnabled": bool,
                "id": "str",
                "inboundIpAddressOverride": "str",
                "internalInboundIpAddresses": ["str"],
                "kind": "str",
                "linuxOutboundIpAddresses": ["str"],
                "name": "str",
                "remoteDebugEnabled": bool,
                "type": "str",
                "windowsOutboundIpAddresses": ["str"],
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_diagnostics(self, resource_group):
        response = await self.client.app_service_environments.list_diagnostics(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_diagnostics_item(self, resource_group):
        response = await self.client.app_service_environments.get_diagnostics_item(
            resource_group_name=resource_group.name,
            name="str",
            diagnostics_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_inbound_network_dependencies_endpoints(self, resource_group):
        response = self.client.app_service_environments.get_inbound_network_dependencies_endpoints(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_multi_role_pools(self, resource_group):
        response = self.client.app_service_environments.list_multi_role_pools(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_multi_role_pool(self, resource_group):
        response = await self.client.app_service_environments.get_multi_role_pool(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_create_or_update_multi_role_pool(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_create_or_update_multi_role_pool(
                resource_group_name=resource_group.name,
                name="str",
                multi_role_pool_envelope={
                    "computeMode": "str",
                    "id": "str",
                    "instanceNames": ["str"],
                    "kind": "str",
                    "name": "str",
                    "sku": {
                        "capabilities": [{"name": "str", "reason": "str", "value": "str"}],
                        "capacity": 0,
                        "family": "str",
                        "locations": ["str"],
                        "name": "str",
                        "size": "str",
                        "skuCapacity": {
                            "default": 0,
                            "elasticMaximum": 0,
                            "maximum": 0,
                            "minimum": 0,
                            "scaleType": "str",
                        },
                        "tier": "str",
                    },
                    "type": "str",
                    "workerCount": 0,
                    "workerSize": "str",
                    "workerSizeId": 0,
                },
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_update_multi_role_pool(self, resource_group):
        response = await self.client.app_service_environments.update_multi_role_pool(
            resource_group_name=resource_group.name,
            name="str",
            multi_role_pool_envelope={
                "computeMode": "str",
                "id": "str",
                "instanceNames": ["str"],
                "kind": "str",
                "name": "str",
                "sku": {
                    "capabilities": [{"name": "str", "reason": "str", "value": "str"}],
                    "capacity": 0,
                    "family": "str",
                    "locations": ["str"],
                    "name": "str",
                    "size": "str",
                    "skuCapacity": {"default": 0, "elasticMaximum": 0, "maximum": 0, "minimum": 0, "scaleType": "str"},
                    "tier": "str",
                },
                "type": "str",
                "workerCount": 0,
                "workerSize": "str",
                "workerSizeId": 0,
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_multi_role_pool_instance_metric_definitions(self, resource_group):
        response = self.client.app_service_environments.list_multi_role_pool_instance_metric_definitions(
            resource_group_name=resource_group.name,
            name="str",
            instance="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_multi_role_metric_definitions(self, resource_group):
        response = self.client.app_service_environments.list_multi_role_metric_definitions(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_multi_role_pool_skus(self, resource_group):
        response = self.client.app_service_environments.list_multi_role_pool_skus(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_test_upgrade_available_notification(self, resource_group):
        response = await self.client.app_service_environments.test_upgrade_available_notification(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_upgrade(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_upgrade(
                resource_group_name=resource_group.name,
                name="str",
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_multi_role_usages(self, resource_group):
        response = self.client.app_service_environments.list_multi_role_usages(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_operations(self, resource_group):
        response = await self.client.app_service_environments.list_operations(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_outbound_network_dependencies_endpoints(self, resource_group):
        response = self.client.app_service_environments.get_outbound_network_dependencies_endpoints(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_private_endpoint_connection_list(self, resource_group):
        response = self.client.app_service_environments.get_private_endpoint_connection_list(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_private_endpoint_connection(self, resource_group):
        response = await self.client.app_service_environments.get_private_endpoint_connection(
            resource_group_name=resource_group.name,
            name="str",
            private_endpoint_connection_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_approve_or_reject_private_endpoint_connection(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_approve_or_reject_private_endpoint_connection(
                resource_group_name=resource_group.name,
                name="str",
                private_endpoint_connection_name="str",
                private_endpoint_wrapper={
                    "id": "str",
                    "ipAddresses": ["str"],
                    "kind": "str",
                    "name": "str",
                    "privateEndpoint": {"id": "str"},
                    "privateLinkServiceConnectionState": {
                        "actionsRequired": "str",
                        "description": "str",
                        "status": "str",
                    },
                    "provisioningState": "str",
                    "type": "str",
                },
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_delete_private_endpoint_connection(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_delete_private_endpoint_connection(
                resource_group_name=resource_group.name,
                name="str",
                private_endpoint_connection_name="str",
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_private_link_resources(self, resource_group):
        response = await self.client.app_service_environments.get_private_link_resources(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_reboot(self, resource_group):
        response = await self.client.app_service_environments.reboot(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_resume(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_resume(
                resource_group_name=resource_group.name,
                name="str",
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_app_service_plans(self, resource_group):
        response = self.client.app_service_environments.list_app_service_plans(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_web_apps(self, resource_group):
        response = self.client.app_service_environments.list_web_apps(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_suspend(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_suspend(
                resource_group_name=resource_group.name,
                name="str",
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_usages(self, resource_group):
        response = self.client.app_service_environments.list_usages(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_worker_pools(self, resource_group):
        response = self.client.app_service_environments.list_worker_pools(
            resource_group_name=resource_group.name,
            name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_get_worker_pool(self, resource_group):
        response = await self.client.app_service_environments.get_worker_pool(
            resource_group_name=resource_group.name,
            name="str",
            worker_pool_name="str",
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_begin_create_or_update_worker_pool(self, resource_group):
        response = await (
            await self.client.app_service_environments.begin_create_or_update_worker_pool(
                resource_group_name=resource_group.name,
                name="str",
                worker_pool_name="str",
                worker_pool_envelope={
                    "computeMode": "str",
                    "id": "str",
                    "instanceNames": ["str"],
                    "kind": "str",
                    "name": "str",
                    "sku": {
                        "capabilities": [{"name": "str", "reason": "str", "value": "str"}],
                        "capacity": 0,
                        "family": "str",
                        "locations": ["str"],
                        "name": "str",
                        "size": "str",
                        "skuCapacity": {
                            "default": 0,
                            "elasticMaximum": 0,
                            "maximum": 0,
                            "minimum": 0,
                            "scaleType": "str",
                        },
                        "tier": "str",
                    },
                    "type": "str",
                    "workerCount": 0,
                    "workerSize": "str",
                    "workerSizeId": 0,
                },
                api_version="2024-04-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_update_worker_pool(self, resource_group):
        response = await self.client.app_service_environments.update_worker_pool(
            resource_group_name=resource_group.name,
            name="str",
            worker_pool_name="str",
            worker_pool_envelope={
                "computeMode": "str",
                "id": "str",
                "instanceNames": ["str"],
                "kind": "str",
                "name": "str",
                "sku": {
                    "capabilities": [{"name": "str", "reason": "str", "value": "str"}],
                    "capacity": 0,
                    "family": "str",
                    "locations": ["str"],
                    "name": "str",
                    "size": "str",
                    "skuCapacity": {"default": 0, "elasticMaximum": 0, "maximum": 0, "minimum": 0, "scaleType": "str"},
                    "tier": "str",
                },
                "type": "str",
                "workerCount": 0,
                "workerSize": "str",
                "workerSizeId": 0,
            },
            api_version="2024-04-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_worker_pool_instance_metric_definitions(self, resource_group):
        response = self.client.app_service_environments.list_worker_pool_instance_metric_definitions(
            resource_group_name=resource_group.name,
            name="str",
            worker_pool_name="str",
            instance="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_web_worker_metric_definitions(self, resource_group):
        response = self.client.app_service_environments.list_web_worker_metric_definitions(
            resource_group_name=resource_group.name,
            name="str",
            worker_pool_name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_worker_pool_skus(self, resource_group):
        response = self.client.app_service_environments.list_worker_pool_skus(
            resource_group_name=resource_group.name,
            name="str",
            worker_pool_name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_app_service_environments_list_web_worker_usages(self, resource_group):
        response = self.client.app_service_environments.list_web_worker_usages(
            resource_group_name=resource_group.name,
            name="str",
            worker_pool_name="str",
            api_version="2024-04-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: send_sms_to_multiple_recipients_sample_async.py
DESCRIPTION:
    This sample demonstrates sending an SMS message to multiple recipients. The SMS client is 
    authenticated using a connection string.
USAGE:
    python send_sms_to_multiple_recipients_sample_async.py
    Set the environment variable with your own value before running the sample:
    1) COMMUNICATION_SAMPLES_CONNECTION_STRING - the connection string in your ACS resource
    2) AZURE_PHONE_NUMBER - a phone number with SMS capabilities in your ACS resource
"""

import os
import sys
import asyncio
from azure.communication.sms.aio import SmsClient

sys.path.append("..")


class SmsMultipleRecipientsSampleAsync(object):

    connection_string = os.getenv("COMMUNICATION_LIVETEST_STATIC_CONNECTION_STRING")
    phone_number = os.getenv("SMS_PHONE_NUMBER")

    async def send_sms_to_multiple_recipients_async(self):
        if not self.connection_string or not self.phone_number:
            raise ValueError(
                '''Environment variables COMMUNICATION_LIVETEST_STATIC_CONNECTION_STRING and SMS_PHONE_NUMBER must be 
                set''')

        sms_client = SmsClient.from_connection_string(self.connection_string)

        async with sms_client:
            try:
                # calling send() with sms values
                sms_responses = await sms_client.send(
                    from_=self.phone_number,
                    to=[self.phone_number, self.phone_number],
                    message="Hello World via SMS",
                    enable_delivery_report=True,  # optional property
                    tag="custom-tag",
                )  # optional property

                for sms_response in sms_responses:
                    if sms_response.successful:
                        print(
                            "Message with message id {} was successful sent to {}".format(
                                sms_response.message_id, sms_response.to
                            )
                        )
                    else:
                        print(
                            "Message failed to send to {} with the status code {} and error: {}".format(
                                sms_response.to, sms_response.http_status_code, sms_response.error_message
                            )
                        )
            except Exception:
                print(Exception)
                pass


if __name__ == "__main__":
    sample = SmsMultipleRecipientsSampleAsync()
    asyncio.run(sample.send_sms_to_multiple_recipients_async())



# coding=utf-8
# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------

"""
FILE: sample_manage_projects.py

DESCRIPTION:
    This sample demonstrates some common authoring operation snippets with the ConversationAuthoringClient.

USAGE:
    python sample_manage_projects.py

    Set the environment variables with your own values before running the sample:
    1) AZURE_CONVERSATIONS_ENDPOINT             - endpoint for your CLU resource.
    2) AZURE_CONVERSATIONS_KEY                  - API key for your CLU resource.
    3) AZURE_CONVERSATIONS_PROJECT_NAME         - project name for your existing CLU conversations project
"""

import uuid


def sample_export_project():
    import os
    from azure.core.rest import HttpRequest
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.language.conversations.authoring import ConversationAuthoringClient

    clu_endpoint = os.environ["AZURE_CONVERSATIONS_ENDPOINT"]
    clu_key = os.environ["AZURE_CONVERSATIONS_KEY"]
    existing_project_name = os.environ["AZURE_CONVERSATIONS_PROJECT_NAME"]

    client = ConversationAuthoringClient(
        clu_endpoint, AzureKeyCredential(clu_key)
    )
    poller = client.begin_export_project(
        project_name=existing_project_name,
        string_index_type="Utf16CodeUnit",
        exported_project_format="Conversation"
    )
    job_state = poller.result()
    print(f"Export project status: {job_state['status']}")
    request = HttpRequest("GET", job_state["resultUrl"])
    response = client.send_request(request)
    exported_project = response.json()
    return exported_project


def sample_import_project(exported_project, project_name):
    import os
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.language.conversations.authoring import ConversationAuthoringClient

    clu_endpoint = os.environ["AZURE_CONVERSATIONS_ENDPOINT"]
    clu_key = os.environ["AZURE_CONVERSATIONS_KEY"]

    print(f"Importing project as '{project_name}'")
    client = ConversationAuthoringClient(
        clu_endpoint, AzureKeyCredential(clu_key)
    )
    poller = client.begin_import_project(
        project_name=project_name,
        project=exported_project
    )
    response = poller.result()
    print(f"Import project status: {response['status']}")
    return project_name


def sample_train_model(project_name):
    import os
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.language.conversations.authoring import ConversationAuthoringClient

    clu_endpoint = os.environ["AZURE_CONVERSATIONS_ENDPOINT"]
    clu_key = os.environ["AZURE_CONVERSATIONS_KEY"]

    client = ConversationAuthoringClient(
        clu_endpoint, AzureKeyCredential(clu_key)
    )
    print(f"Training model under label 'sample'.")

    poller = client.begin_train(
        project_name=project_name,
        configuration={"modelLabel": "sample", "trainingMode": "standard"},
    )

    response = poller.result()
    print(f"Train model status: {response['status']}")


def sample_deploy_model(project_name):
    import os
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.language.conversations.authoring import ConversationAuthoringClient

    clu_endpoint = os.environ["AZURE_CONVERSATIONS_ENDPOINT"]
    clu_key = os.environ["AZURE_CONVERSATIONS_KEY"]

    deployment_name = "production"

    client = ConversationAuthoringClient(
        clu_endpoint, AzureKeyCredential(clu_key)
    )

    print(f"Deploying 'sample' model to 'production'.")
    poller = client.begin_deploy_project(
        project_name=project_name,
        deployment_name=deployment_name,
        deployment={"trainedModelLabel": "sample"},
    )
    response = poller.result()
    print(f"Model '{response['modelId']}' deployed to '{response['deploymentName']}'")


def sample_delete_project(project_name):
    import os
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.language.conversations.authoring import ConversationAuthoringClient

    clu_endpoint = os.environ["AZURE_CONVERSATIONS_ENDPOINT"]
    clu_key = os.environ["AZURE_CONVERSATIONS_KEY"]

    client = ConversationAuthoringClient(
        clu_endpoint, AzureKeyCredential(clu_key)
    )

    poller = client.begin_delete_project(
        project_name=project_name
    )
    poller.result()
    print(f"Deleted project {project_name}")


if __name__ == '__main__':
    project_name = "test_project" + str(uuid.uuid4())
    try:
        print("Exporting project...")
        project = sample_export_project()
        print("Importing project...")
        project_name = sample_import_project(project, project_name)
        print("Training model...")
        sample_train_model(project_name)
        print("Deploying model...")
        sample_deploy_model(project_name)
    finally:
        print("Deleting project...")
        sample_delete_project(project_name)



# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: delete_sip_trunk_sample_async.py
DESCRIPTION:
    This sample shows the usage of asynchronous SIP routing client for deleting the configuration
    of a single SIP trunk.

USAGE:
    python delete_sip_trunk_sample_async.py
    Set the environment variables with your own values before running the sample:
    1) COMMUNICATION_SAMPLES_CONNECTION_STRING - the connection string in your ACS account
    2) COMMUNICATION_SAMPLES_TRUNK_FQDN - fqdn of the trunk to be deleted
"""

import os
import asyncio
from azure.communication.phonenumbers.siprouting.aio import SipRoutingClient

connection_string = os.getenv("COMMUNICATION_SAMPLES_CONNECTION_STRING")
client = SipRoutingClient.from_connection_string(connection_string)


async def delete_sip_trunk_sample():
    trunk_fqdn = os.getenv("COMMUNICATION_SAMPLES_TRUNK_FQDN")
    async with client:
        await client.delete_trunk(trunk_fqdn)


if __name__ == "__main__":
    asyncio.run(delete_sip_trunk_sample())



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: sample_analyze_receipts.py

DESCRIPTION:
    This sample demonstrates how to analyze and extract common fields from receipts,
    using a pre-trained receipt model.

    See fields found on a receipt here:
    https://aka.ms/azsdk/documentintelligence/receiptfieldschema

USAGE:
    python sample_analyze_receipts.py

    Set the environment variables with your own values before running the sample:
    1) DOCUMENTINTELLIGENCE_ENDPOINT - the endpoint to your Document Intelligence resource.
    2) DOCUMENTINTELLIGENCE_API_KEY - your Document Intelligence API key.
"""

import os


def analyze_receipts():
    path_to_sample_documents = os.path.abspath(
        os.path.join(
            os.path.abspath(__file__),
            "..",
            "./sample_forms/receipt/contoso-allinone.jpg",
        )
    )

    # [START analyze_receipts]
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.documentintelligence import DocumentIntelligenceClient
    from azure.ai.documentintelligence.models import AnalyzeResult

    def _format_price(price_dict):
        if price_dict is None:
            return "N/A"
        return "".join([f"{p}" for p in price_dict.values()])

    endpoint = os.environ["DOCUMENTINTELLIGENCE_ENDPOINT"]
    key = os.environ["DOCUMENTINTELLIGENCE_API_KEY"]

    document_intelligence_client = DocumentIntelligenceClient(endpoint=endpoint, credential=AzureKeyCredential(key))
    with open(path_to_sample_documents, "rb") as f:
        poller = document_intelligence_client.begin_analyze_document("prebuilt-receipt", body=f, locale="en-US")
    receipts: AnalyzeResult = poller.result()

    if receipts.documents:
        for idx, receipt in enumerate(receipts.documents):
            print(f"--------Analysis of receipt #{idx + 1}--------")
            print(f"Receipt type: {receipt.doc_type if receipt.doc_type else 'N/A'}")
            if receipt.fields:
                merchant_name = receipt.fields.get("MerchantName")
                if merchant_name:
                    print(
                        f"Merchant Name: {merchant_name.get('valueString')} has confidence: "
                        f"{merchant_name.confidence}"
                    )
                transaction_date = receipt.fields.get("TransactionDate")
                if transaction_date:
                    print(
                        f"Transaction Date: {transaction_date.get('valueDate')} has confidence: "
                        f"{transaction_date.confidence}"
                    )
                items = receipt.fields.get("Items")
                if items:
                    print("Receipt items:")
                    for idx, item in enumerate(items.get("valueArray")):
                        print(f"...Item #{idx + 1}")
                        item_description = item.get("valueObject").get("Description")
                        if item_description:
                            print(
                                f"......Item Description: {item_description.get('valueString')} has confidence: "
                                f"{item_description.confidence}"
                            )
                        item_quantity = item.get("valueObject").get("Quantity")
                        if item_quantity:
                            print(
                                f"......Item Quantity: {item_quantity.get('valueString')} has confidence: "
                                f"{item_quantity.confidence}"
                            )
                        item_total_price = item.get("valueObject").get("TotalPrice")
                        if item_total_price:
                            print(
                                f"......Total Item Price: {_format_price(item_total_price.get('valueCurrency'))} has confidence: "
                                f"{item_total_price.confidence}"
                            )
                subtotal = receipt.fields.get("Subtotal")
                if subtotal:
                    print(
                        f"Subtotal: {_format_price(subtotal.get('valueCurrency'))} has confidence: {subtotal.confidence}"
                    )
                tax = receipt.fields.get("TotalTax")
                if tax:
                    print(f"Total tax: {_format_price(tax.get('valueCurrency'))} has confidence: {tax.confidence}")
                tip = receipt.fields.get("Tip")
                if tip:
                    print(f"Tip: {_format_price(tip.get('valueCurrency'))} has confidence: {tip.confidence}")
                total = receipt.fields.get("Total")
                if total:
                    print(f"Total: {_format_price(total.get('valueCurrency'))} has confidence: {total.confidence}")
            print("--------------------------------------")
    # [END analyze_receipts]


if __name__ == "__main__":
    from azure.core.exceptions import HttpResponseError
    from dotenv import find_dotenv, load_dotenv

    try:
        load_dotenv(find_dotenv())
        analyze_receipts()
    except HttpResponseError as error:
        # Examples of how to check an HttpResponseError
        # Check by error code:
        if error.error is not None:
            if error.error.code == "InvalidImage":
                print(f"Received an invalid image error: {error.error}")
            if error.error.code == "InvalidRequest":
                print(f"Received an invalid request error: {error.error}")
            # Raise the error again after printing it
            raise
        # If the inner error is None and then it is possible to check the message to get more information:
        if "Invalid request".casefold() in error.message.casefold():
            print(f"Uh-oh! Seems there was an invalid request: {error}")
        # Raise the error again
        raise



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from typing import Any, IO, Union

from azure.identity import DefaultAzureCredential

from azure.mgmt.dataprotection import DataProtectionMgmtClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-dataprotection
# USAGE
    python validate_restore.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = DataProtectionMgmtClient(
        credential=DefaultAzureCredential(),
        subscription_id="04cf684a-d41f-4550-9f70-7708a3a2283b",
    )

    response = client.backup_instances.begin_validate_for_restore(
        resource_group_name="000pikumar",
        vault_name="PratikPrivatePreviewVault1",
        backup_instance_name="testInstance1",
        parameters={
            "restoreRequestObject": {
                "objectType": "AzureBackupRecoveryPointBasedRestoreRequest",
                "recoveryPointId": "hardcodedRP",
                "restoreTargetInfo": {
                    "datasourceAuthCredentials": {
                        "objectType": "SecretStoreBasedAuthCredentials",
                        "secretStoreResource": {
                            "secretStoreType": "AzureKeyVault",
                            "uri": "https://samplevault.vault.azure.net/secrets/credentials",
                        },
                    },
                    "datasourceInfo": {
                        "datasourceType": "Microsoft.DBforPostgreSQL/servers/databases",
                        "objectType": "Datasource",
                        "resourceID": "/subscriptions/f75d8d8b-6735-4697-82e1-1a7a3ff0d5d4/resourceGroups/viveksipgtest/providers/Microsoft.DBforPostgreSQL/servers/viveksipgtest/databases/targetdb",
                        "resourceLocation": "",
                        "resourceName": "targetdb",
                        "resourceType": "Microsoft.DBforPostgreSQL/servers/databases",
                        "resourceUri": "",
                    },
                    "datasourceSetInfo": {
                        "datasourceType": "Microsoft.DBforPostgreSQL/servers/databases",
                        "objectType": "DatasourceSet",
                        "resourceID": "/subscriptions/f75d8d8b-6735-4697-82e1-1a7a3ff0d5d4/resourceGroups/viveksipgtest/providers/Microsoft.DBforPostgreSQL/servers/viveksipgtest",
                        "resourceLocation": "",
                        "resourceName": "viveksipgtest",
                        "resourceType": "Microsoft.DBforPostgreSQL/servers",
                        "resourceUri": "",
                    },
                    "objectType": "RestoreTargetInfo",
                    "recoveryOption": "FailIfExists",
                    "restoreLocation": "southeastasia",
                },
                "sourceDataStoreType": "VaultStore",
                "sourceResourceId": "/subscriptions/f75d8d8b-6735-4697-82e1-1a7a3ff0d5d4/resourceGroups/viveksipgtest/providers/Microsoft.DBforPostgreSQL/servers/viveksipgtest/databases/testdb",
            }
        },
    ).result()
    print(response)


# x-ms-original-file: specification/dataprotection/resource-manager/Microsoft.DataProtection/stable/2024-04-01/examples/BackupInstanceOperations/ValidateRestore.json
if __name__ == "__main__":
    main()
